@@ -5,7 +5,7 @@ use warnings;
 use utf8;
 use Regexp::Grammars;
 
-our $VERSION = '1.008';
+our $VERSION = '1.009';
 
 sub new {
 	my ($class) = @_;
@@ -85,10 +85,10 @@ sub PT::ClassGroups::X {
 sub PT::Group::X {
     my ($class, $className) = @_;
 
-    return (       $class->{Comment}
-                || $class->{Function}
-                || $class->{Parent}
-				|| $class->{Packages} )->X($className);
+    return (	   $class->{Comment}
+		|| $class->{Function}
+		|| $class->{Parent}
+		|| $class->{Packages} )->X($className);
 }
 
 sub PT::Packages::X {
@@ -113,8 +113,8 @@ sub PT::PackageList::X {
 sub PT::Package::X {
 	my ($class, $className) = @_;
 
-	return (	   $class->{PackageWithConstructor}
-            	|| $class->{PackageWithoutConstructor} )->X($className);
+	return (	$class->{PackageWithConstructor}
+            	     || $class->{PackageWithoutConstructor} )->X($className);
 }
 
 sub PT::PackageWithConstructor::X {
@@ -129,14 +129,14 @@ sub PT::PackageWithConstructor::X {
 		my $parameters = join(",", @parameters);
 
 		my $packageWithConstructor = "use " . $packageName . ";\n"
-									  . "my \$" . $object . " = " . $packageName . "->"
-									  . $constructor . "(" . $parameters . ");\n";
+			                     . "my \$" . $object . " = " . $packageName . "->"
+					     . $constructor . "(" . $parameters . ");\n";
 		return $packageWithConstructor;
 	}
 
 	my $packageWithConstructor = "use " . $packageName . ";\n"
-								 . "my \$" . $object . " = " . $packageName
-								 . "->" . $constructor . "();\n";
+				     . "my \$" . $object . " = " . $packageName
+				     . "->" . $constructor . "();\n";
 	return $packageWithConstructor;
 }
 
@@ -356,9 +356,12 @@ sub PT::ForRange::X {
 sub PT::LowerRange::X {
     my ($class, $className) = @_;
     my $number = (     $class->{Number}
-                    || $class->{VariableName}
-                    || $class->{ArrayElement}
-                    || $class->{HashElement} )->X($className);
+		    || $class->{VariableName}
+		    || $class->{ArrayElement}
+		    || $class->{HashElement}
+		    || $class->{ClassAccessor}
+		    || $class->{ClassFunctionReturn}
+		    || $class->{FunctionReturn} )->X($className);
 
     return $number;
 }
@@ -366,9 +369,12 @@ sub PT::LowerRange::X {
 sub PT::UpperRange::X {
     my ($class, $className) = @_;
     my $number = (     $class->{Number}
-                    || $class->{VariableName}
-                    || $class->{ArrayElement}
-                    || $class->{HashElement} )->X($className);
+		    || $class->{VariableName}
+		    || $class->{ArrayElement}
+		    || $class->{HashElement}
+		    || $class->{ClassAccessor}
+		    || $class->{ClassFunctionReturn}
+		    || $class->{FunctionReturn} )->X($className);
 
     return $number;
 }
@@ -531,7 +537,7 @@ sub PT::Statement::X {
                 || $class->{Return}
                 || $class->{Last}
                 || $class->{Next}
-				|| $class->{ObjectCall} )->X($className);
+                || $class->{ObjectCall} )->X($className);
 }
 
 sub PT::ObjectCall::X {
@@ -813,11 +819,11 @@ sub PT::ObjectFunctionCall::X {
 
 	my $objectFunctionCall;
 	if(exists $class->{Parameters}) {
-		my @parameters = $class->{Parameters}->X($className);
-		my $parameters = join(",", @parameters);
-		$objectFunctionCall = "\$" . $object . "->" . $functionName . "(" . $parameters . ")";
+	    my @parameters = $class->{Parameters}->X($className);
+	    my $parameters = join(",", @parameters);
+	    $objectFunctionCall = "\$" . $object . "->" . $functionName . "(" . $parameters . ")";
 	} else {
-		$objectFunctionCall = "\$" . $object . "->" . $functionName . "()";
+	    $objectFunctionCall = "\$" . $object . "->" . $functionName . "()";
 	}
 
 	return $objectFunctionCall;
@@ -1131,7 +1137,7 @@ sub PT::LogicalOr::X {
 
 my $parser = qr {
     <nocontext:>
-	<debug: off>
+    <debug: off>
 
     <Lang>
     <objrule:  PT::Lang>                       <[Class]>+
@@ -1149,13 +1155,13 @@ my $parser = qr {
     <objrule:  PT::Parent>                     <TokenParent> <LParen> <ClassNames> <RParen> <SemiColon>
     <objrule:  PT::ClassNames>                 <[ClassName]>+ % <Comma>
 
-	<objrule:  PT::Packages>				   <LParen> <PackageList> <RParen> <SemiColon>
-	<objrule:  PT::PackageList>			       <[Package]>+ % <Comma>
-	<objrule:  PT::Package>					   <PackageWithConstructor> | <PackageWithoutConstructor>
+    <objrule:  PT::Packages>			<LParen> <PackageList> <RParen> <SemiColon>
+    <objrule:  PT::PackageList>		<[Package]>+ % <Comma>
+    <objrule:  PT::Package>			<PackageWithConstructor> | <PackageWithoutConstructor>
     <objrule:  PT::PackageWithConstructor>     [!] <Object> <Equal> <PackageName> <Dot> <Constructor> <LParen> <Parameters>? <RParen>
-	<objrule:  PT::PackageName>				   <[PackageDir]>+ % (::)
+    <objrule:  PT::PackageName>		<[PackageDir]>+ % (::)
     <objrule:  PT::PackageWithoutConstructor>  <PackageName>
-	<objrule:  PT::Constructor>                [a-zA-Z]+?
+    <objrule:  PT::Constructor>                [a-zA-Z]+?
     <objrule:  PT::Object>                     [a-zA-Z]+?
     <objrule:  PT::PackageDir>                 [a-zA-Z]+?
 
@@ -1179,16 +1185,20 @@ my $parser = qr {
     <objrule:  PT::For>                        <TokenFor> <Var> <VariableName> <LParen> <ForRange> <RParen> <CodeBlock>
     <objrule:  PT::ForRange>                   <LowerRange> <Dot><Dot><Dot> <UpperRange>
     <objrule:  PT::LowerRange>                 <Number> | <VariableName> | <ArrayElement> | <HashElement>
+						| <ClassAccessor> | <ClassFunctionReturn> | <FunctionReturn>
     <objrule:  PT::UpperRange>                 <Number> | <VariableName> | <ArrayElement> | <HashElement>
+						| <ClassAccessor> | <ClassFunctionReturn> | <FunctionReturn>
 
     <objrule:  PT::IfElse>                     <If> <ElsIf>? <Else>?
     <objrule:  PT::If>                         <TokenIf> <LParen> <BoolExpression> <RParen> <CodeBlock>
+    
     <objrule:  PT::BoolExpression>             <BoolOperands> <BoolOperatorExpression>?
     <objrule:  PT::BoolOperatorExpression>     <BoolOperator> <BoolOperands>
     <objrule:  PT::BoolOperands>               <RealNumber> | <String> | <ScalarVariable> | <ArrayElement> | <HashElement>
-											   | <ClassAccessor> | <ClassFunctionReturn> | <FunctionReturn>
+						| <ClassAccessor> | <ClassFunctionReturn> | <FunctionReturn>
     <objrule:  PT::BoolOperator>               <GreaterThan> | <LessThan> | <Equals> | <GreaterThanEquals> | <LessThanEquals>
                                                | <StringEquals> | <StringNotEquals> | <NotEqulas> | <LogicalAnd> | <LogicalOr>
+                                               
     <objrule:  PT::ElsIf>                      <[ElsIfChain]>+
     <objrule:  PT::ElsIfChain>                 <TokenElsIf> <LParen> <BoolExpression> <RParen> <CodeBlock>
     <objrule:  PT::Else>                       <TokenElse> <CodeBlock>
@@ -1197,7 +1207,7 @@ my $parser = qr {
                                                | <ObjectCall> | <Assignment> | <Return> | <Last> | <Next>
     <objrule:  PT::ClassFunctionCall>          <TokenClass> <Dot> <FunctionName> <LParen> <Parameters>? <RParen> <SemiColon>
 
-	<objrule:  PT::ObjectCall>				    <ObjectFunctionCall> <SemiColon>
+    <objrule:  PT::ObjectCall>			<ObjectFunctionCall> <SemiColon>
 
     <objrule:  PT::VariableDeclaration>        <ArrayDeclaration> | <HashDeclaration> | <ScalarDeclaration>
 
@@ -1217,7 +1227,7 @@ my $parser = qr {
     <objrule:  PT::ArrayList>                  <LBracket> <ListElements> <RBracket>
     <objrule:  PT::ListElements>               .{0} | <[ListElement]>+ % <Comma>
     <objrule:  PT::ListElement>                <RealNumber> | <String> | <ClassFunctionReturn> | <FunctionReturn>
-											   | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
+						| <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
 
     <objrule:  PT::HashDeclaration>            <Var> <VariableName> <Equal> <HashRef> <SemiColon>
     <objrule:  PT::HashRef>                    <LBrace> <KeyValuePairs> <RBrace>
@@ -1225,7 +1235,7 @@ my $parser = qr {
     <objrule:  PT::KeyValue>                   <PairKey> <Colon> <PairValue>
     <objrule:  PT::PairKey>                    <Number> | <String>
     <objrule:  PT::PairValue>                  <RealNumber> | <String> | <ClassFunctionReturn> | <FunctionReturn>
-											   | <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
+						| <ArrayElement> | <HashElement> | <ArrayList> | <HashRef> | <VariableName>
 
     <objrule:  PT::FunctionCall>               <FunctionName> <LParen> <Parameters>? <RParen> <SemiColon>
     <objrule:  PT::Parameters>                 <[Param]>+ % <Comma>
@@ -1235,13 +1245,17 @@ my $parser = qr {
 
     <objrule:  PT::ScalarAssignment>           <ScalarVariable> <Equal> <RHS> <SemiColon>
     <objtoken: PT::ScalarVariable>             [a-zA-Z]+
+    
     <objrule:  PT::RHS>                        <RealNumber> | <FunctionReturn> | <ArrayElement> | <HashElement>
                                                | <ScalarVariable> | <Calc> | <ArrayList> | <HashRef> | <ClassAccessor>
                                                | <ClassFunctionReturn> | <String> | <STDIN> | <ObjectFunctionCall>
+                                               
     <objrule:  PT::FunctionReturn>             <FunctionName> <LParen> <Parameters>? <RParen>
+    
     <objrule:  PT::ArrayElement>               <ArrayName> <[ArrayAccess]>+
     <objrule:  PT::ArrayAccess>                <LBracket> <Number> <RBracket>
     <objrule:  PT::ArrayName>                  [a-zA-Z]+?
+    
     <objrule:  PT::HashElement>                <HashName> <[HashAccess]>+
     <objrule:  PT::HashAccess>                 <LBrace> <HashKey> <RBrace>
     <objtoken: PT::HashName>                   [a-zA-Z]+?
@@ -1283,7 +1297,7 @@ my $parser = qr {
 
     <objtoken: PT::TokenSTDIN>                 STDIN
 
-	<objrule:  PT::ObjectFunctionCall>		   [!] <Object> <Dot> <FunctionName> <LParen> <Parameters>? <RParen>
+    <objrule:  PT::ObjectFunctionCall>		[!] <Object> <Dot> <FunctionName> <LParen> <Parameters>? <RParen>
 
     <objtoken: PT::LogicalAnd>                 \&\&
     <objtoken: PT::LogicalOr>                  \|\|
